#comment out if not prerel
%define prel		beta3

#rel to bump
%define rel		10

%define major		2
%define api		5.1
%define libluajit	%mklibname %{name} %{api} %{major}
%define devluajit	%mklibname %{name} %{api} -d

%define	tarname		LuaJIT

Name:			luajit
Version:		2.1.0
Release:		%mkrel %{?prel:0.%prel.}%{rel}
Summary:		Just-In-Time Compiler for the Lua programming language
Group:			Development/Other
License:		MIT
Url:			http://luajit.org/luajit.html
Source:			http://luajit.org/download/%{tarname}-%{version}%{?prel:-%prel}.tar.gz
Patch01:		CVE-2020-15890.patch

Requires:		%{name}-common = %{version}-%{release}

%description
LuaJIT has been successfully used as a scripting middle-ware in games,
3D modelers, numerical simulations, trading platforms and many other
specialty applications.
It combines high flexibility with high performance and an unmatched low
memory footprint: less than 125K for the VM plus less than 85K for the
JIT compiler (on x86).
LuaJIT has been in continuous development since 2005. It is widely considered
to be one of the fastest dynamic language implementations.

%files
%doc COPYRIGHT README
%{_bindir}/%{name}-%{version}%{?prel:-%prel}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%package common
Summary:	Just-In-Time Compiler for the Lua programming language
Group:		System/Libraries
BuildArch:	noarch
Obsoletes:	%{_lib}luajit-5.1-common < 2.0.3-3

%description common
LuaJIT has been successfully used as a scripting middle-ware in games,
3D modelers, numerical simulations, trading platforms and many other
specialty applications.
It combines high flexibility with high performance and an unmatched low
memory footprint: less than 125K for the VM plus less than 85K for the
JIT compiler (on x86).
LuaJIT has been in continuous development since 2005. It is widely considered
to be one of the fastest dynamic language implementations.

%files common
%{_datadir}/%{name}-%{version}%{?prel:-%prel}/jit/*.lua

%package -n %{libluajit}
Summary:	Just-In-Time Compiler for the Lua programming language
Group:		System/Libraries
Requires:	%{name}-common = %{version}-%{release}
Obsoletes:	%{_lib}luajit-5.1_2 < 2.0.3-3

%description -n %{libluajit}
LuaJIT has been successfully used as a scripting middle-ware in games,
3D modelers, numerical simulations, trading platforms and many other
specialty applications.
It combines high flexibility with high performance and an unmatched low
memory footprint: less than 125K for the VM plus less than 85K for the
JIT compiler (on x86).
LuaJIT has been in continuous development since 2005. It is widely considered
to be one of the fastest dynamic language implementations.

%files -n %{libluajit}
%{_libdir}/lib%{name}*.so.%{major}
%{_libdir}/lib%{name}*.so.%{version}

%package -n %{devluajit}
Summary:	Just-In-Time Compiler for the Lua programming language
Group:		Development/Other
Requires:	%{libluajit} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{tarname}-devel = %{version}-%{release}
Obsoletes:	%{_lib}luajit-5.1-devel < 2.0.3-3

%description -n %{devluajit}
This package contains header files needed by developers.

%files -n %{devluajit}
%{_includedir}/luajit*/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/libluajit-%{api}.so

%prep
%setup -q -n %{tarname}-%{version}%{?prel:-%prel}
%autopatch -p1

%build
%ifarch	x86_64 aarch64
%make_build amalg \
 	Q= E=@: PREFIX=%{_prefix} MULTILIB=%{_lib} \
	TARGET_CFLAGS=-DMULTIARCH_PATH='\"%{_libdir}/\"' \
	CCDEBUG="%{optflags}" \
	XCFLAGS="-DLUAJIT_ENABLE_LUA52COMPAT" \
	TARGET_STRIP=:
%else
%make_build amalg \
	Q= E=@: PREFIX=%{_prefix} MULTILIB=%{_lib} \
	INSTALL_LIB="%{buildroot}%{_libdir}" \
	CCDEBUG="%{optflags}" \
	XCFLAGS="-DLUAJIT_ENABLE_LUA52COMPAT" \
	TARGET_STRIP=:
%endif

%install
%make_install PREFIX=%{_prefix} MULTILIB=%{_lib} INSTALL_LIB=%{buildroot}%{_libdir}

ln -sf %{_libdir}/libluajit-%{api}.so.%{version} %{buildroot}%{_libdir}/libluajit-%{api}.so

ln -sf %{_bindir}/luajit-%{version}%{?prel:-%prel} %{buildroot}%{_bindir}/luajit

# We don't package static libraries
rm -rf %{buildroot}%{_libdir}/libluajit-%{api}.a


%changelog
* Tue Mar 15 2022 umeabot <umeabot> 2.1.0-0.beta3.10.mga9
+ Revision: 1793752
- Mageia 9 Mass Rebuild

* Tue Jan 04 2022 wally <wally> 2.1.0-0.beta3.9.mga9
+ Revision: 1766841
- properly fix paths in pkg-config .pc file

* Fri Aug 21 2020 mrambo3501 <mrambo3501> 2.1.0-0.beta3.8.mga8
+ Revision: 1617725
- add debian patch which fixes CVE-2020-15890 (mga#27021)

* Sun Apr 05 2020 wally <wally> 2.1.0-0.beta3.7.mga8
+ Revision: 1564978
- fix paths in pkg-config .pc file

* Sun Apr 05 2020 wally <wally> 2.1.0-0.beta3.6.mga8
+ Revision: 1564974
- set correct architecture-specific library path (lib vs. lib64)

* Thu Feb 13 2020 umeabot <umeabot> 2.1.0-0.beta3.5.mga8
+ Revision: 1514943
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.1.0-0.beta3.4.mga7
+ Revision: 1299370
- Mageia 7 Mass Rebuild

* Fri Jul 13 2018 wally <wally> 2.1.0-0.beta3.3.mga7
+ Revision: 1243416
- fix binary symlink

* Fri Jul 13 2018 wally <wally> 2.1.0-0.beta3.2.mga7
+ Revision: 1243398
- build with LUAJIT_ENABLE_LUA52COMPAT
- increase build time verbosity
- own includedir

* Mon Feb 12 2018 wally <wally> 2.1.0-0.beta3.1.mga7
+ Revision: 1200654
- 2.1.0 beta3

* Sat Sep 30 2017 daviddavid <daviddavid> 2.0.4-4.mga7
+ Revision: 1161850
- fix debug information package

* Mon Feb 15 2016 umeabot <umeabot> 2.0.4-3.mga6
+ Revision: 961300
- Mageia 6 Mass Rebuild

* Thu Oct 29 2015 daviddavid <daviddavid> 2.0.4-2.mga6
+ Revision: 896455
- do not strip libraries to fix empty debuginfo

* Tue Jun 23 2015 akien <akien> 2.0.4-1.mga6
+ Revision: 839967
- Version 2.0.4

* Wed Oct 15 2014 umeabot <umeabot> 2.0.3-4.mga5
+ Revision: 740534
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 akien <akien> 2.0.3-3.mga5
+ Revision: 737429
- Fix libname to follow the Mageia policy
- Make the -common package noarch
- Do not provide the static library

* Tue Sep 16 2014 umeabot <umeabot> 2.0.3-2.mga5
+ Revision: 682039
- Mageia 5 Mass Rebuild

* Tue Apr 29 2014 akien <akien> 2.0.3-1.mga5
+ Revision: 618787
- New version 2.0.3

* Sat Oct 19 2013 umeabot <umeabot> 2.0.2-2.mga4
+ Revision: 532670
- Mageia 4 Mass Rebuild

* Thu Aug 22 2013 barjac <barjac> 2.0.2-1.mga4
+ Revision: 469205
- new version 2.0.2
- removed beta clutter from spec since new full versions are regularly released
- used %%(minor} to fix symlink

* Mon Jan 14 2013 barjac <barjac> 2.0.0-0.2.beta11.1.mga3
+ Revision: 388063
- fix release format until next version - note in spec
- new beta
- drop patch

* Sun Jul 08 2012 barjac <barjac> 2.0.0-0.2.beta10.mga3
+ Revision: 268791
- add missing symlink

* Sat Jul 07 2012 barjac <barjac> 2.0.0-0.1.beta10.mga3
+ Revision: 268735
- imported package luajit

